@@ -40,6 +40,10 @@ public:
 
     _subVectorSizes = svs;
 
+    // Compute offsets of each subvector
+    _subVectorOffsets.resize(_subVectorSizes.size(), 0);
+    std::partial_sum(_subVectorSizes.begin(), --_subVectorSizes.end(), ++_subVectorOffsets.begin());
+
     size_t N = std::accumulate(_subVectorSizes.begin(), _subVectorSizes.end(), static_cast<std::size_t>(0));
 
     // cannot do this already in the constructor as the size is unknown at that point
@@ -217,6 +221,9 @@ protected:
   /// Sizes of each sub-vector, i.e. each coupling data
   std::vector<size_t> _subVectorSizes;
 
+  /// Offsets of each sub-vector in concatenated data, i.e. each coupling data
+  std::vector<size_t> _subVectorOffsets;
+
   /** @brief maximum number of non-const time windows, i.e., after this number of time windows,
    *  the preconditioner is frozen with the current weights and becomes a constant preconditioner
    */
