@@ -2,12 +2,10 @@
 
 #include <memory>
 
-namespace precice {
-namespace m2n {
+namespace precice::m2n {
 
 class M2N;
 
 using PtrM2N = std::shared_ptr<M2N>;
 
-} // namespace m2n
-} // namespace precice
+} // namespace precice::m2n
