@@ -3,8 +3,7 @@
 #include "logging/Logger.hpp"
 #include "mapping/BarycentricBaseMapping.hpp"
 
-namespace precice {
-namespace mapping {
+namespace precice::mapping {
 
 /**
  * @brief Mapping using orthogonal projection to nearest triangle/edge/vertex and
@@ -18,9 +17,11 @@ public:
   /// Computes the projections and interpolation relations.
   void computeMapping() final override;
 
+  /// name of the lci mapping
+  std::string getName() const final override;
+
 private:
   logging::Logger _log{"mapping::LinearCellInterpolationMappingMapping"};
 };
 
-} // namespace mapping
-} // namespace precice
+} // namespace precice::mapping
