@@ -5,8 +5,7 @@
 #include "logging/Logger.hpp"
 #include "mapping/NearestNeighborBaseMapping.hpp"
 
-namespace precice {
-namespace mapping {
+namespace precice::mapping {
 
 /// Mapping using nearest neighboring vertices and their local gradient values.
 class NearestNeighborGradientMapping : public NearestNeighborBaseMapping {
@@ -22,13 +21,15 @@ public:
   /// Calculates the offsets needed for the gradient mappings after calculating the matched vertices
   void onMappingComputed(mesh::PtrMesh origins, mesh::PtrMesh searchSpace) final override;
 
+  /// name of the nng mapping
+  std::string getName() const final override;
+
 protected:
   /// @copydoc Mapping::mapConservative
-  void mapConservative(DataID inputDataID, DataID outputDataID) final override;
+  void mapConservative(const time::Sample &inData, Eigen::VectorXd &outData) final override;
 
   /// @copydoc Mapping::mapConsistent
-  void mapConsistent(DataID inputDataID, DataID outputDataID) final override;
+  void mapConsistent(const time::Sample &inData, Eigen::VectorXd &outData) final override;
 };
 
-} // namespace mapping
-} // namespace precice
+} // namespace precice::mapping
