@@ -7,8 +7,7 @@
 
 #include "EigenHelperFunctions.hpp"
 
-namespace precice {
-namespace utils {
+namespace precice::utils {
 
 void shiftSetFirst(
     Eigen::MatrixXd &A, const Eigen::VectorXd &v)
@@ -29,7 +28,7 @@ void appendFront(
   } else {
     PRECICE_ASSERT(v.size() == n, v.size(), A.rows());
     A.conservativeResize(n, m + 1);
-    //A.topRightCorner(n, m) = A.topLeftCorner(n, m); // bad error, reason unknown!
+    // A.topRightCorner(n, m) = A.topLeftCorner(n, m); // bad error, reason unknown!
     for (auto i = A.cols() - 1; i > 0; i--)
       A.col(i) = A.col(i - 1);
     A.col(0) = v;
@@ -55,5 +54,4 @@ void append(
   v(n) = value;
 }
 
-} // namespace utils
-} // namespace precice
+} // namespace precice::utils
