@@ -2,18 +2,19 @@
 
 #include "testing/Testing.hpp"
 
-#include <precice/SolverInterface.hpp>
+#include <precice/precice.hpp>
 #include <vector>
 
 BOOST_AUTO_TEST_SUITE(Integration)
 BOOST_AUTO_TEST_SUITE(Serial)
 BOOST_AUTO_TEST_SUITE(Lifecycle)
 // Test representing the minimal lifecylce with explicit finalization.
-// This shows how to manually finalize MPI etc without using the SolverInterface.
+// This shows how to manually finalize MPI etc without using the Participant.
+PRECICE_TEST_SETUP("SolverOne"_on(1_rank), "SolverTwo"_on(1_rank))
 BOOST_AUTO_TEST_CASE(ConstructAndExplicitFinalize)
 {
-  PRECICE_TEST("SolverOne"_on(1_rank), "SolverTwo"_on(1_rank));
-  precice::SolverInterface interface(context.name, context.config(), context.rank, context.size);
+  PRECICE_TEST();
+  precice::Participant interface(context.name, context.config(), context.rank, context.size);
 
   interface.finalize();
 }
